@@ -232,6 +232,8 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => true)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
+          is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => true)
+          is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => true)
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_router_id').with(:value => '')
           is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
@@ -245,6 +247,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/aodh').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh_plugin').with(:value => false)
           is_expected.to contain_tempest_config('service_available/gnocchi').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/panko').with(:value => false)
           is_expected.to contain_tempest_config('service_available/horizon').with(:value => true)
           is_expected.to contain_tempest_config('service_available/neutron').with(:value => true)
           is_expected.to contain_tempest_config('service_available/mistral').with(:value => false)
@@ -255,7 +258,9 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/swift').with(:value => false)
           is_expected.to contain_tempest_config('service_available/trove').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ironic').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/watcher').with(:value => false)
           is_expected.to contain_tempest_config('service_available/zaqar').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/congress').with(:value => false)
           is_expected.to contain_tempest_config('service_available/designate').with(:value => false)
           is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
